%Q7_Earth_Moon_L1
function Q7_Earth_Moon_L1

%Determine L1 point

%Mass of Earth and Moon /kg
M_e = 5.972e24;
M_m = 7.35e22;

%Fraction of Earth-Moon separation (60 Earth radii)
x = linspace(0.42,0.92,1000);

%Solve for L1 point
f = ( x./ (1-x) ).^2;
g = (M_e/M_m)*( 1 - x.^3 );

d = abs(f-g);
i = find( d==min(d) ); i = i(1);
x1 = x(i);

%Plot graphical solution for L1 point
fsize = 18;
plot(x,f,x,g); hold on; set(gca,'fontsize',fsize); grid on;
title(['L1 is at x_1=',num2str(x1)],'fontsize',fsize);
xlabel('x = r/(60*R_E)','fontsize',fsize);
legend({'f(x)','g(x)'},'fontsize',fsize);
xlimits = get(gca,'xlim'); ylimits = get(gca,'ylim');
plot( [x1,x1],ylimits,'r--');
plot( xlimits,[1,1]*( x1/(1-x1) )^2 ,'r--' );
print(gcf,'Q7 f(x) vs g(x).png','-dpng','-r300')
close(gcf);

%Plot GPE per unit mass and total energy per unit mass
R = 6371e3;
r = linspace(30*R,59*R,1000);
[phi,E_over_m,g] = gcalc( M_e, M_m, r, R );
[phi1,E_over_m1,g1] = gcalc( M_e, M_m, x1*60*R, R );
plot( r/R, phi, r/R, E_over_m ); hold on;
set(gca,'fontsize',fsize); grid on;
xlimits = get(gca,'xlim'); ylimits = get(gca,'ylim');
plot( 60*[x1,x1],ylimits,'r--');
plot( xlimits,E_over_m1*[1,1],'r--');
plot( xlimits,phi1*[1,1],'r--');
xlabel('r/R_E','fontsize',fsize);
ylabel('Energy per unit mass (J/kg)','fontsize',fsize);
legend({'GPE','GPE + KE'},'fontsize',fsize)
print(gcf,'energy per unit mass.png','-dpng','-r300');
close(gcf);

%Plot g(r) vs r
plot( r/R, g );
hold on; set(gca,'fontsize',fsize); grid on;
xlimits = get(gca,'xlim'); ylimits = get(gca,'ylim');
plot( 60*[x1,x1],ylimits,'r--');
plot( xlimits,g1*[1,1],'r--');
xlabel('r/R_E','fontsize',fsize);
ylabel('g /N/kg','fontsize',fsize);
title('g(r) vs r','fontsize',fsize);
print(gcf,'g vs r.png','-dpng','-r300');
close(gcf);

%%

function [phi,E_over_m,g] = gcalc( M_e, M_m, r, R )
G = 6.67e-11;
phi = -G*M_e./r -G*M_m./( 60*R - r );
E_over_m = 0.5*(r.^2)*G*M_e/( (60*R)^3 ) + phi;
g = G*M_e./(r.^2) - G*M_m./( (60*R - r).^2 );

%End of code