%Q9_black_hole_infall

%Solar mass /kg
M_s = 332837*5.972e24;

%Mass of Gargantua in solar masses
M = 100*1e6*M_s;

%Universal Gravitational constant G /Nkg^-2m^2
G = 6.67e-11;

%Speed of light /ms^-1
c = 2.9988e8;

%Asronomical unit /m
AU = 1.496e11;

%Fontsize for graphs
fsize = 18;

%Schwarzchild radius of Gargantua /m
R = 2*G*M/c^2;

%Period of Miller's planet /s
P = ( 2*pi/sqrt(G*M) ) * ( (2*R)^(3/2) ) ;

%Numerically compute infall time using Euler method
dr = (1e-4)*2*R;
v=0; t=0; r0 = 2*R; r = r0; n=1;
while r>R
    r(n+1) = r(n) - dr;
    v(n+1) = sqrt(2*G*M)*sqrt( 1/r(n+1) - 1/r0 );
    t(n+1) = t(n) + dr/v(n+1);
    n = n + 1;
end

%Compute infall time exactly via integration
rr = linspace(r0,R,1000);
s = sqrt( rr./( r0 - rr ) );
te = sqrt(r0/(2*G*M))*( r0*pi/2 - r0*atan(s) + (r0-rr).*s );
vv = sqrt(2*G*M)*sqrt( 1./rr - 1/r0 );

%Plot range vs infall time
plot( t,r/R,te,rr/R ); set(gca,'fontsize',fsize); grid on;
xlabel('Infall time t /s','fontsize',fsize);
ylabel('r/R','fontsize',fsize);
title(['Gargantua infall time. t=',...
    num2str(te(end),4),'s at r=R=',num2str(R/AU),'AU'],'fontsize',fsize);
legend({'Numeric','Exact'},'fontsize',fsize);
print( gcf,'gargantua infall.png','-dpng','-r300');
close(gcf);

%Plot v/c vs time
plot( te, vv/c ); set(gca,'fontsize',fsize); grid on;
xlabel('Infall time t /s','fontsize',fsize);
ylabel('v/c','fontsize',fsize);
title(['Ratio of infall speed to speed of light. v_{max}/c=',...
num2str(vv(end)/c,3)],'fontsize',fsize);
print( gcf,'gargantua infall speed.png','-dpng','-r300');
close(gcf);

%End of code

    


